summaryrefslogtreecommitdiff
path: root/pstcache.c
diff options
context:
space:
mode:
authorPeter Åstrand <astrand@cendio.com>2006-01-24 12:40:24 +0000
committerPeter Åstrand <astrand@cendio.com>2006-01-24 12:40:24 +0000
commitacffcd7e9c0beda659eab3a0962c8bd6b21d8aac (patch)
tree9a1c27b534b9bcf33a1863ebd28a6b0bef3b6ed0 /pstcache.c
parent960a02dfeb773e85882f3872090129cbc7b38ded (diff)
downloadrdesktop-acffcd7e9c0beda659eab3a0962c8bd6b21d8aac.zip
Applied patch #1390148 from Ilya Konstantinov: Refactoring of color depth code.
git-svn-id: svn://svn.code.sf.net/p/rdesktop/code/trunk/rdesktop@1041 423420c4-83ab-492f-b58f-81f9feb106b5
Diffstat (limited to 'pstcache.c')
-rw-r--r--pstcache.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/pstcache.c b/pstcache.c
index 702b862..7bf0678 100644
--- a/pstcache.c
+++ b/pstcache.c
@@ -24,7 +24,7 @@
#define IS_PERSISTENT(id) (id < 8 && g_pstcache_fd[id] > 0)
-extern int g_server_bpp;
+extern int g_server_depth;
extern BOOL g_bitmap_cache;
extern BOOL g_bitmap_cache_persist_enable;
extern BOOL g_bitmap_cache_precache;
@@ -131,8 +131,8 @@ pstcache_enumerate(uint8 id, HASH_KEY * keylist)
{
memcpy(keylist[idx], cellhdr.key, sizeof(HASH_KEY));
- /* Pre-cache (not possible for 8bpp because 8bpp needs a colourmap) */
- if (g_bitmap_cache_precache && cellhdr.stamp && g_server_bpp > 8)
+ /* Pre-cache (not possible for 8 bit colour depth cause it needs a colourmap) */
+ if (g_bitmap_cache_precache && cellhdr.stamp && g_server_depth > 8)
pstcache_load_bitmap(id, idx);
/* Sort by stamp */
@@ -179,7 +179,7 @@ pstcache_init(uint8 cache_id)
return False;
}
- g_pstcache_Bpp = (g_server_bpp + 7) / 8;
+ g_pstcache_Bpp = (g_server_depth + 7) / 8;
sprintf(filename, "cache/pstcache_%d_%d", cache_id, g_pstcache_Bpp);
DEBUG(("persistent bitmap cache file: %s\n", filename));